#ifndef NT2_INCLUDE_FUNCTIONS_LAGUERRE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LAGUERRE_HPP_INCLUDED

#include <nt2/polynomials/include/functions/laguerre.hpp>

#endif
